Crate dremoc_sync

Crate dremoc_sync 

Modules

broadcast
A multi-producer, multi-consumer broadcast queue with receivers that may be located on remote endpoints.
mpsc
Multi producer single customer remote channel.
oneshot
A one-shot channel is used for sending a single message between asynchronous, remote tasks.
watch
A single-producer, multi-consumer remote channel that only retains the last sent value.

Structs

RwLock
A lock that allows reading and writing of a shared value, possibly stored on a remote endpoint.
RwLockReadGuard
RAII structure used to release the shared read access of a lock when dropped.
RwLockWriteGuard
RAII structure used to release the exclusive write access of a lock when dropped.

Enums

CommitError
An error occurred during committing an RwLock value
LockError
An error occurred during locking of an RwLock value for reading or writing.