pub enum StreamError {
Lagged,
RemoteReceive(RecvError),
RemoteConnect(ConnectError),
RemoteListen(ListenerError),
}Expand description
An error occurred during receiving over a broadcast channel receiver stream.
Variants
Lagged
The receiver stream lagged too far behind.
The next value will be the oldest message still retained by the channel.
RemoteReceive(RecvError)
Receiving from a remote endpoint failed.
RemoteConnect(ConnectError)
Connecting a sent channel failed.
RemoteListen(ListenerError)
Listening for a connection from a received channel failed.
Implementations