dremoc_sync::broadcast

Struct Receiver

pub struct Receiver<T, Codec = Json, const BUFFER: usize = remoc::::rch::broadcast::receiver::Receiver::{constant#0}, const MAX_ITEM_SIZE: usize = remoc::::rch::broadcast::receiver::Receiver::{constant#1}> { /* private fields */ }
Receiving-half of the broadcast channel.

Can be sent over a remote channel.

This can be converted into a Stream of values by wrapping it into a ReceiverStream.

Implementations

Source

impl<T, Codec, const BUFFER: usize, const MAX_ITEM_SIZE: usize> Receiver<T, Codec, BUFFER, MAX_ITEM_SIZE>
where T: RemoteSend, Codec: Codec,

pub async fn recv(&mut self) -> Result<T, RecvError>

Receives the next value for this receiver.

pub fn try_recv(&mut self) -> Result<T, TryRecvError>

Attempts to return a pending value on this receiver without awaiting.

pub fn max_item_size(&self) -> usize

The maximum item size in bytes.

pub fn set_max_item_size<const NEW_MAX_ITEM_SIZE: usize>( self, ) -> Receiver<T, Codec, BUFFER, NEW_MAX_ITEM_SIZE>

Sets the maximum item size in bytes.

pub fn remote_max_item_size(&self) -> Option<usize>

The maximum item size of the remote sender.

If this is larger than max_item_size sending of oversized items will succeed but receiving will fail with a MaxItemSizeExceeded error.