Sender

Struct Sender 

pub struct Sender<T, Codec = Json> { /* private fields */ }
Sending-half of the broadcast channel.

Cannot be sent over a remote channel. Use feeder to obtain an mpsc sender that feeds this broadcast sender and can be sent over a remote channel.

Implementations

Source

impl<T, Codec> Sender<T, Codec>
where T: RemoteSend + Clone, Codec: Codec,

pub fn send(&self, value: T) -> Result<(), SendError<T>>

Attempts to send a value to all active receivers.

No back-pressure is provided.

pub fn subscribe<const RECEIVE_BUFFER: usize>( &self, send_buffer: usize, ) -> Receiver<T, Codec, RECEIVE_BUFFER>

Creates a new receiver that will receive values sent after this call to subscribe.

pub fn subscribe_with_max_item_size<const RECEIVE_BUFFER: usize, const MAX_ITEM_SIZE: usize>( &self, send_buffer: usize, ) -> Receiver<T, Codec, RECEIVE_BUFFER, MAX_ITEM_SIZE>

Creates a new receiver with a custom maximum item size.

pub fn feeder<const SEND_BUFFER: usize>(&self) -> Sender<T, Codec, SEND_BUFFER>

Creates an mpsc sender that feeds values to this broadcast sender.

The mpsc sender can be sent over a remote channel. All feeders are disconnected once all receivers are disconnected.

pub fn receiver_count(&self) -> usize

Returns the number of active receivers.