pub enum SendError<T> {
Closed(T),
RemoteSend(SendErrorKind),
RemoteConnect(ConnectError),
RemoteListen(ListenerError),
RemoteForward,
}Expand description
An error occurred during sending over an mpsc channel.
Variants
Closed(T)
The remote end closed the channel.
RemoteSend(SendErrorKind)
Sending to a remote endpoint failed.
RemoteConnect(ConnectError)
Connecting a sent channel failed.
RemoteListen(ListenerError)
Listening for a received channel failed.
RemoteForward
Forwarding at a remote endpoint to another remote endpoint failed.
Implementations
Sourceimpl<T> SendError<T>
impl<T> SendError<T>
Sourcepub fn closed_reason(&self) -> Option<ClosedReason>
pub fn closed_reason(&self) -> Option<ClosedReason>
Returns the reason for why the channel has been disconnected.
Returns None if the error is not due to the channel being disconnected. Currently this can only happen if a serialization error occurred.
Sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
True, if the remote endpoint closed the channel, was dropped or the connection failed.
Sourcepub fn is_final(&self) -> bool
👎Deprecated: a remoc::rch::mpsc::SendError is always final
pub fn is_final(&self) -> bool
Returns whether the error is final, i.e. no further send operation can succeed.
Sourcepub fn is_item_specific(&self) -> bool
pub fn is_item_specific(&self) -> bool
Whether the error is caused by the item to be sent.
Sourcepub fn without_item(self) -> SendError<()>
pub fn without_item(self) -> SendError<()>
Returns the error without the contained item.