TryRecvError

Enum TryRecvError 

pub enum TryRecvError {
    Closed,
    Empty,
    RemoteReceive(RecvError),
    RemoteConnect(ConnectError),
    RemoteListen(ListenerError),
}
An error occurred during trying to receive over an mpsc channel.

Variants



Closed

All channel senders have been dropped.



Empty

Currently no value is ready to receive, but values may still arrive in the future.



RemoteReceive(RecvError)

Receiving from a remote endpoint failed.



RemoteConnect(ConnectError)

Connecting a sent channel failed.



RemoteListen(ListenerError)

Listening for a connection from a received channel failed.

Implementations

Source

impl TryRecvError

pub fn is_final(&self) -> bool

Returns whether the error is final, i.e. no further receive operation can succeed.