pub enum TrySendError<T> {
Closed(T),
Full(T),
RemoteSend(SendErrorKind),
RemoteConnect(ConnectError),
RemoteListen(ListenerError),
RemoteForward,
}Expand description
An error occurred during trying to send over an mpsc channel.
Variants
Closed(T)
The remote end closed the channel.
Full(T)
The data could not be sent on the channel because the channel is currently full and sending would require blocking.
RemoteSend(SendErrorKind)
Sending to a remote endpoint failed.
RemoteConnect(ConnectError)
Connecting a sent channel failed.
RemoteListen(ListenerError)
Listening for a received channel failed.
RemoteForward
Forwarding at a remote endpoint to another remote endpoint failed.
Implementations
Sourceimpl<T> TrySendError<T>
impl<T> TrySendError<T>
Sourcepub fn is_disconnected(&self) -> bool
pub fn is_disconnected(&self) -> bool
True, if the remote endpoint closed the channel, was dropped or the connection failed.
Sourcepub fn is_final(&self) -> bool
pub fn is_final(&self) -> bool
Returns whether the error is final, i.e. no further send operation can succeed.
Sourcepub fn is_item_specific(&self) -> bool
pub fn is_item_specific(&self) -> bool
Whether the error is caused by the item to be sent.