Distributor

Struct Distributor 

pub struct Distributor<T, Codec = Json, const BUFFER: usize = remoc::::rch::mpsc::distributor::Distributor::{constant#0}, const MAX_ITEM_SIZE: usize = remoc::::rch::mpsc::distributor::Distributor::{constant#1}> { /* private fields */ }
Distributes items of an mpsc channel over multiple receivers.

Distribution is stopped and all subscribers are closed when the distributor is dropped.

Implementations

Source

impl<T, Codec, const BUFFER: usize, const MAX_ITEM_SIZE: usize> Distributor<T, Codec, BUFFER, MAX_ITEM_SIZE>
where T: RemoteSend + Clone, Codec: Codec,

pub async fn subscribe( &self, ) -> Option<(Receiver<T, Codec, BUFFER, MAX_ITEM_SIZE>, DistributedReceiverHandle)>

Creates a new subscribed receiver and returns it along with its handle.

pub async fn closed(&self)

Waits until the distributor is closed.

The distributor closes when all subscribers are closed and wait_on_empty is false, or when the upstream sender is dropped or fails.