pub struct Receiver<T, Codec = Json, const MAX_ITEM_SIZE: usize = remoc::::rch::oneshot::receiver::Receiver::{constant#0}>(/* private fields */);Expand description
Receive a value from the associated sender.
Await this future to receive the value.
Implementations
Sourceimpl<T, Codec, const MAX_ITEM_SIZE: usize> Receiver<T, Codec, MAX_ITEM_SIZE>
impl<T, Codec, const MAX_ITEM_SIZE: usize> Receiver<T, Codec, MAX_ITEM_SIZE>
Sourcepub fn try_recv(&mut self) -> Result<T, TryRecvError>
pub fn try_recv(&mut self) -> Result<T, TryRecvError>
Attempts to receive a value transmitted by the sender.
Sourcepub fn max_item_size(&self) -> usize
pub fn max_item_size(&self) -> usize
The maximum item size in bytes.
Sourcepub fn set_max_item_size<const NEW_MAX_ITEM_SIZE: usize>(
self,
) -> Receiver<T, Codec, NEW_MAX_ITEM_SIZE> ⓘ
pub fn set_max_item_size<const NEW_MAX_ITEM_SIZE: usize>( self, ) -> Receiver<T, Codec, NEW_MAX_ITEM_SIZE> ⓘ
Sets the maximum item size in bytes.
Sourcepub fn remote_max_item_size(&self) -> Option<usize>
pub fn remote_max_item_size(&self) -> Option<usize>
The maximum item size of the remote sender.
If this is larger than max_item_size sending of oversized items will succeed but receiving will fail with a MaxItemSizeExceeded error.