Sender

Struct Sender 

pub struct Sender<T, Codec = Json>(/* private fields */);
Sends a value to the associated receiver.

Implementations

Source

impl<T, Codec> Sender<T, Codec>
where T: RemoteSend, Codec: Codec,

pub fn send(self, value: T) -> Result<(), SendError<T>>

Sends a value over this channel.

pub async fn closed(&self)

Completes when the receiver has been closed, dropped or the connection failed.

Use closed_reason to obtain the cause for closure.

pub fn closed_reason(&self) -> Option<ClosedReason>

Returns the reason for why the channel has been closed.

Returns None if the channel is not closed.

pub fn is_closed(&self) -> bool

Returns whether the receiver has been closed, dropped or the connection failed.

Use closed_reason to obtain the cause for closure.

pub fn max_item_size(&self) -> usize

The maximum allowed item size in bytes.

pub fn set_max_item_size(&mut self, max_item_size: usize)

Sets the maximum allowed item size in bytes.