RwLock

Struct RwLock 

pub struct RwLock<T, Codec = Default> { /* private fields */ }
A lock that allows reading and writing of a shared value, possibly stored on a remote endpoint.

This can be cloned and sent to remote endpoints

Implementations

Source

impl<T, Codec> RwLock<T, Codec>

pub fn host(&self) -> Option<&Arc<TokioRwLock<T>>>

Returns host if it exist

pub async fn host_read(&self) -> Option<TokioRwLockReadGuard<'_, T>>

Locks the host shared value for reading and returns a reference to it, without synchronizing with remote endpoints

pub async fn host_write(&self) -> Option<TokioRwLockWriteGuard<'_, T>>

Locks the host shared value for reading and writing and returns a mutable reference to it, without synchronizing with remote endpoints

Source

impl<T: RemoteSend + Clone + Sync, Codec: Codec> RwLock<T, Codec>

pub fn new(value: T) -> Self

Creates a new RwLock<T> with an host with the specified shared value.

pub async fn read(&self) -> Result<RwLockReadGuard<'_, T, Codec>, LockError>

Locks the current shared value for reading and returns a reference to it.

pub async fn write(&self) -> Result<RwLockWriteGuard<'_, T, Codec>, LockError>

Locks the current shared value for reading and writing and returns a mutable reference to it.

To commit the new value RwLockWriteGuard::commit must be called, otherwise the changes will be lost.