pub struct RwLockReadGuard<'a, T, Codec = Default> { /* private fields */ }Expand description
RAII structure used to release the shared read access of a lock when dropped.
As long as this is held, no write access to the lock can occur.