pub struct RwLockWriteGuard<'a, T, Codec = Default> { /* private fields */ }Expand description
RAII structure used to release the exclusive write access of a lock when dropped.
To commit changes commit must be called. Dropping the guard will result in the changes to be not applied to the shared value.
Implementations
Sourceimpl<'a, T: RemoteSend, Codec: Codec> RwLockWriteGuard<'a, T, Codec>
impl<'a, T: RemoteSend, Codec: Codec> RwLockWriteGuard<'a, T, Codec>
Sourcepub async fn commit(self) -> Result<(), CommitError>
pub async fn commit(self) -> Result<(), CommitError>
Consumes the guard and commits the changes to the shared value.