Sender

Struct Sender 

pub struct Sender<T, Codec = Json> { /* private fields */ }
Send values to the associated Receiver, which may be located on a remote endpoint.

Instances are created by the channel function.

Implementations

Source

impl<T, Codec> Sender<T, Codec>
where T: Send + 'static,

pub fn send(&self, value: T) -> Result<(), SendError>

Sends a value over this channel, notifying all receivers.

This method fails if all receivers have been dropped or become disconnected.

Error reporting

Sending and error reporting are done asynchronously. Thus, the reporting of an error may be delayed and this function may return errors caused by previous invocations.

pub fn send_modify<F>(&self, func: F)
where F: FnOnce(&mut T),

Modifies the watched value and notifies all receivers.

This method never fails, even if all receivers have been dropped or become disconnected.

Panics

This method panics if calling func results in a panic.

pub fn send_replace(&self, value: T) -> T

Sends a new value via the channel, notifying all receivers and returning the previous value in the channel.

This method never fails, even if all receivers have been dropped or become disconnected.

pub fn borrow(&self) -> Ref<'_, T>

Returns a reference to the most recently sent value.

pub async fn closed(&self)

Completes when all receivers have been dropped or the connection failed.

pub fn is_closed(&self) -> bool

Returns whether all receivers have been dropped or the connection failed.

pub fn subscribe(&self) -> Receiver<T, Codec>

Creates a new receiver subscribed to this sender.

pub fn error(&self) -> Option<SendError>

Returns the error that occurred during sending to a remote endpoint, if any.

Error reporting

Sending and error reporting are done asynchronously. Thus, the reporting of an error may be delayed.

pub fn clear_error(&mut self)

Clears the error that occurred during sending to a remote endpoint.

pub fn check(&mut self) -> Result<(), SendError>

Checks that no item-specific send error has occurred.

This method clears non-item-specific errors present on the channel.

Error reporting

Sending and error reporting are done asynchronously. Thus, the reporting of an error may be delayed.

To verify that no item-specific send error has occurred during the lifetime of the channel, call this method after the channel is closed, i.e. closed has returned or is_closed is true.

pub fn max_item_size(&self) -> usize

Maximum allowed item size in bytes.

pub fn set_max_item_size(&mut self, max_item_size: usize)

Sets the maximum allowed item size in bytes.