Crate dremoc_sync

Modules

  • A multi-producer, multi-consumer broadcast queue with receivers that may be located on remote endpoints.
  • Multi producer single customer remote channel.
  • A one-shot channel is used for sending a single message between asynchronous, remote tasks.
  • A single-producer, multi-consumer remote channel that only retains the last sent value.

Structs

  • A lock that allows reading and writing of a shared value, possibly stored on a remote endpoint.
  • RAII structure used to release the shared read access of a lock when dropped.
  • RAII structure used to release the exclusive write access of a lock when dropped.

Enums

  • An error occurred during committing an RwLock value
  • An error occurred during locking of an RwLock value for reading or writing.