pub struct Sender<T, Codec = Json>(/* private fields */);Expand description
Sends a value to the associated receiver.
Implementations
Sourceimpl<T, Codec> Sender<T, Codec>where
T: RemoteSend,
Codec: Codec,
impl<T, Codec> Sender<T, Codec>where
T: RemoteSend,
Codec: Codec,
Sourcepub async fn closed(&self)
pub async fn closed(&self)
Completes when the receiver has been closed, dropped or the connection failed.
Use closed_reason to obtain the cause for closure.
Sourcepub fn closed_reason(&self) -> Option<ClosedReason>
pub fn closed_reason(&self) -> Option<ClosedReason>
Returns the reason for why the channel has been closed.
Returns None if the channel is not closed.
Sourcepub fn is_closed(&self) -> bool
pub fn is_closed(&self) -> bool
Returns whether the receiver has been closed, dropped or the connection failed.
Use closed_reason to obtain the cause for closure.
Sourcepub fn max_item_size(&self) -> usize
pub fn max_item_size(&self) -> usize
The maximum allowed item size in bytes.
Sourcepub fn set_max_item_size(&mut self, max_item_size: usize)
pub fn set_max_item_size(&mut self, max_item_size: usize)
Sets the maximum allowed item size in bytes.